// @ts-check
const { log, errors } = require('cozy-konnector-libs')
const soapRequest = require('easy-soap-request')
const { parseTags, parseValue } = require('./parsing')
const { commanderArretServiceSouscritMesures } = require('./requests/sge')
const xml2js = require('xml2js')

/**
 * @param {string} url
 * @param {string} apiAuthKey
 * @param {string} appLogin
 * @param {string} pointId
 * @param {number} serviceId
 * @return {Promise<string>} User contractId
 */
async function terminateContract(
  url,
  apiAuthKey,
  appLogin,
  contractId,
  pointId,
  serviceId
) {
  log('info', 'activateContract')
  const sgeHeaders = {
    'Content-Type': 'text/xml;charset=UTF-8',
    apikey: apiAuthKey,
  }

  const { response } = await soapRequest({
    url: url,
    headers: sgeHeaders,
    xml: commanderArretServiceSouscritMesures(
      appLogin,
      contractId,
      pointId,
      serviceId
    ),
  }).catch(err => {
    log('error', 'commanderArretServiceSouscritMesures')
    log('error', err)
    throw errors.VENDOR_DOWN
  })

  const parsedReply = await xml2js.parseStringPromise(response.body, {
    tagNameProcessors: [parseTags],
    valueProcessors: [parseValue],
    explicitArray: false,
  })

  try {
    // We don't need any action on reply for now
    return parsedReply
  } catch (error) {
    log('error', 'Error while parsing user contract termination: ' + error)
    throw errors.VENDOR_DOWN
  }
}

module.exports = { terminateContract }
